==> prime_sdk_py-0.3.1-py3-none-any.whl: prime_sdk/get_wallet_deposit_instructions.py <==
# Copyright 2024-present Coinbase Global, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
#  limitations under the License.

from dataclasses import dataclass
from prime_sdk.base_response import BaseResponse
from prime_sdk.client import Client
from typing import List
from prime_sdk.credentials import Credentials
from prime_sdk.utils import append_query_param
from prime_sdk.enums import WalletDepositType


@dataclass
class GetWalletDepositInstructionsRequest:
    portfolio_id: str
    wallet_id: str
    deposit_type: WalletDepositType
    allowed_status_codes: List[int] = None


@dataclass
class GetWalletDepositInstructionsResponse(BaseResponse):
    request: GetWalletDepositInstructionsRequest


class PrimeClient:
    def __init__(self, credentials: Credentials):
        self.client = Client(credentials)

    def get_wallet_deposit_instructions(
            self,
            request: GetWalletDepositInstructionsRequest) -> GetWalletDepositInstructionsResponse:
        path = f"/portfolios/{request.portfolio_id}/wallets/{request.wallet_id}/deposit_instructions"

        query_params = append_query_param("", 'deposit_type', request.deposit_type)

        response = self.client.request("GET", path, query=query_params,
                                       allowed_status_codes=request.allowed_status_codes)
        return GetWalletDepositInstructionsResponse(response.json(), request)

==> prime_sdk_py-0.4.0-py3-none-any.whl: prime_sdk/get_wallet_deposit_instructions.py <==
# Copyright 2024-present Coinbase Global, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from dataclasses import dataclass
from prime_sdk.base_response import BaseResponse
from prime_sdk.client import Client
from typing import List, Optional
from prime_sdk.credentials import Credentials
from prime_sdk.utils import append_query_param
from prime_sdk.enums import WalletDepositType
from prime_sdk.model import Instructions


@dataclass
class GetWalletDepositInstructionsRequest:
    portfolio_id: str
    wallet_id: str
    deposit_type: WalletDepositType
    allowed_status_codes: Optional[List[int]] = None


@dataclass
class GetWalletDepositInstructionsResponse(BaseResponse):
    instructions: Instructions = None


class PrimeClient:
    def __init__(self, credentials: Credentials):
        self.client = Client(credentials)

    def get_wallet_deposit_instructions(self, request: GetWalletDepositInstructionsRequest) -> GetWalletDepositInstructionsResponse:
        path = f"/portfolios/{request.portfolio_id}/wallets/{request.wallet_id}/deposit_instructions"
        query_params = append_query_param("", 'deposit_type', request.deposit_type)
        response = self.client.request("GET", path, query=query_params, allowed_status_codes=request.allowed_status_codes)
        return GetWalletDepositInstructionsResponse(response.json())
